==> vaadin-spring-24.9-20260115.101954-351-sources.jar: com/vaadin/flow/spring/security/VaadinAwareSecurityContextHolderStrategyConfiguration.java <==
/*
 * Copyright 2000-2026 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.spring.security;

import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.context.SecurityContextHolderStrategy;

/**
 * Provides configuration of Vaadin aware {@link SecurityContextHolderStrategy}
 */
@Configuration
public class VaadinAwareSecurityContextHolderStrategyConfiguration {

    /**
     * Registers {@link SecurityContextHolderStrategy} bean.
     * <p>
     * Beans of this type will automatically be used by
     * {@link org.springframework.security.config.annotation.method.configuration.GlobalMethodSecurityConfiguration}
     * to configure the current {@link SecurityContextHolderStrategy}.
     */
    @Bean(name = "VaadinSecurityContextHolderStrategy")
    @ConditionalOnMissingBean
    public VaadinAwareSecurityContextHolderStrategy securityContextHolderStrategy() {
        VaadinAwareSecurityContextHolderStrategy vaadinAwareSecurityContextHolderStrategy = new VaadinAwareSecurityContextHolderStrategy();
        // Use a security context holder that can find the context from Vaadin
        // specific classes
        SecurityContextHolder.setContextHolderStrategy(
                vaadinAwareSecurityContextHolderStrategy);
        return vaadinAwareSecurityContextHolderStrategy;
    }

}

==> vaadin-spring-25.1-20260113.095238-85-sources.jar: com/vaadin/flow/spring/security/VaadinAwareSecurityContextHolderStrategyConfiguration.java <==
/*
 * Copyright 2000-2025 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.spring.security;

import org.springframework.context.annotation.Configuration;
import org.springframework.security.core.context.SecurityContextHolderStrategy;

import com.vaadin.flow.spring.SpringSecurityAutoConfiguration;

/**
 * Provides configuration of Vaadin aware {@link SecurityContextHolderStrategy}
 *
 * @deprecated A {@link SecurityContextHolderStrategy} implementation is now
 *             automatically provided by {@link SpringSecurityAutoConfiguration}
 *             and it is no more necessary to import this configuration class,
 *             which is now no-op. The default strategy implementation is
 *             {@link VaadinAwareSecurityContextHolderStrategy} and can be
 *             overridden by providing a custom bean.
 */
@Deprecated(since = "25.0", forRemoval = true)
@Configuration
public class VaadinAwareSecurityContextHolderStrategyConfiguration {
}
